import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import java.util.*;


/**
 * @stereotype UI 
 */
public class MainMIDlet extends MIDlet
  implements CommandListener
{
  private static final String VERSION_ID = "0.7.18.45";

  private Command     exitCommand;
  private Command     newGameCommand;
  private Command     helpCommand;
  private Display     display;
  private Form        mainForm;

  /**
   * @supplierRole nimCanvas
   * @supplierCardinality 1
   * @link aggregationByValue 
   */
  private NimCanvas   nimCanvas;
  private Form        helpForm;
  private ChoiceGroup levelsChoice;


  public MainMIDlet()
  {
    this.nimCanvas = new NimCanvas( this );
    this.helpForm  = new HelpForm( this );

    // Build Form.
    this.mainForm  = new Form( "O Jogo" );
    this.mainForm.append( new StringItem( "Nome", "PalmNIM" ) );
    this.mainForm.append( new StringItem( "Verso", VERSION_ID ) );
    this.mainForm.append( new StringItem( "Disciplina", "MAC-413" ) );
    this.mainForm.append( new StringItem( "Professor", "Fabio Kon" ) );
    this.mainForm.append( new StringItem( "Autores", "Rubens Altimari & Jorge Del Teglia" ) );
    this.mainForm.append( new StringItem( "Instituo", "USP / IME - 2002" ) );
    this.levelsChoice = createLevelsChoice();
    this.mainForm.append( this.levelsChoice );
    this.mainForm.setTicker( new Ticker( "Copyright 2002  8-)  Rubens Altimari & Jorge Del Teglia" ) );

    // Set up commands.
    this.newGameCommand = new Command( "Jogar!", Command.SCREEN, 2 );
    this.helpCommand    = new Command( "Ajuda", Command.SCREEN, 2 );
    this.exitCommand    = new Command( "Sair", Command.SCREEN, 2 );
    this.mainForm.addCommand( this.newGameCommand );
    this.mainForm.addCommand( this.helpCommand );
    this.mainForm.addCommand( this.exitCommand );
    this.mainForm.setCommandListener( this );
  }


  public void startApp()
  {
    // Set current form.
    this.display = Display.getDisplay( this );
    this.display.setCurrent( this.mainForm );
  }


  public void pauseApp()
  {
  }


  public void destroyApp( boolean uncondition )
  {
    this.nimCanvas  = null;
  }


  public void commandAction( Command c, Displayable d )
  {
    if ( c == this.exitCommand )
    {
      destroyApp( true );
      notifyDestroyed();
    }
    else if ( c == this.newGameCommand )
    {
      Expert expert = Expert.createInstance( this.levelsChoice.getSelectedIndex() );
      this.nimCanvas.startNewGame( expert );
      this.display.setCurrent( this.nimCanvas );
    }
    else if ( c == this.helpCommand )
    {
      this.display.setCurrent( this.helpForm );
    }
  }


  public void goToMainForm()
  {
    this.display.setCurrent( this.mainForm );
  }


  private ChoiceGroup createLevelsChoice()
  {
    ChoiceGroup result = new ChoiceGroup( "Nvel", ChoiceGroup.EXCLUSIVE );
    String[] levels = Expert.getExpertNames();
    for ( int i = 0; i < levels.length; i++ )
    {
      result.append( i + "- " + levels[ i ], null );
    }

    return result;
  }
} // class MainMIDlet



/**
 * Informa as instrues do jogo.
 * @stereotype UI
 */
class HelpForm extends Form
  implements CommandListener
{
  /**
   * @supplierRole theMidlet
   * @supplierCardinality 1 
   */
  private MainMIDlet theMidlet;
  private Command goBackCommand;

  public HelpForm( MainMIDlet theMidlet )
  {
    super( " Ajuda" );

    this.theMidlet  = theMidlet;

    append( new StringItem( "Nome", "PalmNIM" ) );
    append( new StringItem( "Instrues", "Para escolher as fichas, clique em elas e aperte o boto 'Pegar'. Aps o Palm informar qual ser sua prpria jogada, aperte 'Continuar'. Quem escolha a ltima ficha, ganha!" ) );

    this.goBackCommand = new Command( "Voltar", Command.SCREEN, 2 );
    addCommand( this.goBackCommand );
    setCommandListener( this );
  }


  public void commandAction( Command c, Displayable d )
  {
    if ( c == this.goBackCommand )
    {
      this.theMidlet.goToMainForm();
    }
  }
} // class HelpForm



