


/**
 * @stereotype Model 
 */
class Selection
{
  /**
   * Maximo numero de peas por fila.
   */
  private static final int MAX_PIECES = 10;

  /**
   * A fila marcada.
   */
  private int selectedRow;

  /**
   * As peas marcadas nessa fila.
   */
  private boolean[] selectedPieces;


  Selection()
  {
    this.selectedRow    = 0;
    this.selectedPieces = new boolean[ MAX_PIECES ];

    // Todas no marcadas inicialmente.
    cleanRow();
  }


  void selectRow( int row )
  {
    if ( this.selectedRow != row )
    {
      this.selectedRow = row;
      cleanRow();
    }
  }


  /**
   * Seleciona a pea indicada na fila atual.
   *
   * @param numPiece O numero da pea, em [0,MAX_PIECES-1]
   */
  void togglePiece( int numPiece )
  {
    this.selectedPieces[ numPiece ] = !this.selectedPieces[ numPiece ];
  }


  /**
   * @return True if the specified piece is selected.
   */
  boolean isSelected( int row, int col )
  {
    return (this.selectedRow == row) && this.selectedPieces[ col ];
  }


  /**
   * @return O numero da fila selecionada.
   */
  int getSelectedRow()
  {
    return this.selectedRow;
  }


  /**
   * @return O numero de peas selecionadas na fila atual.
   */
  int countPieces()
  {
    int count = 0;
    for ( int i = 0; i < this.selectedPieces.length; i++ )
    {
      if ( this.selectedPieces[ i ] )
        count++;
    }

    return count;
  }


  /**
   * Deseleciona todo.
   */
  void unselectAll()
  {
    cleanRow();
  }


  /**
   *
   * @return Os estados das peas, sendo true selecionado.
   */
  boolean[] getSelectedPieces()
  {
    return this.selectedPieces;
  }


  /**
   * Deseleciona as peas na fila.
   */
  private void cleanRow()
  {
    for ( int i = 0; i < this.selectedPieces.length; i++ )
    {
      this.selectedPieces[ i ] = false;
    }
  }
}

